@@ -1,5 +1,5 @@
 /* This file is part of PHP YAZ.
- * Copyright (C) Index Data 2004-2016
+ * Copyright (C) Index Data 2004-2018
  * See the file LICENSE for details.
  */
 
@@ -832,8 +832,8 @@ PHP_FUNCTION(yaz_hits)
 	} else {
 		WRONG_PARAM_COUNT;
 	}
-	if (searchresult && array_init(searchresult) == FAILURE) {
-		RETURN_FALSE;
+	if (searchresult) {
+		array_init(searchresult);
 	}
 	get_assoc(INTERNAL_FUNCTION_PARAM_PASSTHRU, id, &p);
 
@@ -1858,9 +1858,11 @@ PHP_FUNCTION(yaz_scan)
 	ZOOM_scanset_destroy(p->zoom_scan);
 	p->zoom_scan = 0;
 	if (p) {
-		option_set(p, "number", array_lookup_string(flags_ht, "number"));
-		option_set(p, "position", array_lookup_string(flags_ht, "position"));
-		option_set(p, "stepSize", array_lookup_string(flags_ht, "stepsize"));
+		if (flags_ht) {
+			option_set(p, "number", array_lookup_string(flags_ht, "number"));
+			option_set(p, "position", array_lookup_string(flags_ht, "position"));
+			option_set(p, "stepSize", array_lookup_string(flags_ht, "stepsize"));
+		}
 		p->zoom_scan = ZOOM_connection_scan(p->zoom_conn, query);
 	}
 	release_assoc(p);
@@ -1921,9 +1923,8 @@ PHP_FUNCTION(yaz_scan_result)
 	}
 
 	array_init(return_value);
-
-	if (pval_opt && array_init(pval_opt) == FAILURE) {
-		RETURN_FALSE;
+	if (pval_opt) {
+			array_init(pval_opt);
 	}
 
 	get_assoc(INTERNAL_FUNCTION_PARAM_PASSTHRU, pval_id, &p);
